"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const nd_gpio_rf_1 = require("nd-gpio-rf");
class GpioRFSniffer {
    constructor(RED, node, config) {
        this.RED = RED;
        this.config = config;
        this.node = node;
        this.init();
    }
    init() {
        this.node.status({});
        this.gpio = new nd_gpio_rf_1.GpioRF();
        this.node.on('input', (msg) => {
            this.sniffCode(msg);
        });
        this.node.on('close', () => {
        });
    }
    sniffCode(msg) {
        console.log("Start Sniff......");
        this.node.status({ fill: "yellow", shape: "dot", text: "sniffing" });
        this.gpio.sniff({
            strMicros: msg.payload || this.config.strMicros,
            minMicrotime: msg.minMicrotime || this.config.minMicrotime,
            minCount: msg.minCount || this.config.minCount
        }, (error, codes) => {
            if (!error) {
                msg.payload = codes;
                this.node.status({ fill: "green", shape: "dot", text: "sniff OK" });
                this.node.send(msg);
            }
            else {
                this.node.error(error);
                this.node.status({ fill: "red", shape: "dot", text: error });
            }
        });
        return true;
    }
}
module.exports = (RED) => {
    function CreateNode(config) {
        RED.nodes.createNode(this, config);
        new GpioRFSniffer(RED, this, config);
    }
    RED.nodes.registerType("gpio-rf-sniffer", CreateNode);
};
